/*
    Copyright 2004 James Nash
                                                                                                
    This file is part of Ganesha.
                                                                                                
    Ganesha is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.
                                                                                                
    Ganesha is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU General Public License for more details.
                                                                                                
    You should have received a copy of the GNU General Public License
    along with Ganesha (see the LICENSE file); if not, write to the Free
    Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
    MA  02111-1307  USA
                                                                                                
*/
package com.twiddles.ganesha;

import java.io.*;
/**
   The user's preferences and settings.
   This class keeps track of user settings
   like the last directory that was accessed.

   @author James Nash
*/
public class Settings{

    // the last directory a file was read from
    private static File lastOpenDir = null;

    // the last directory a file was saved to
    private static File lastSaveAsDir = null;



    /**
       Set the last directory used for a "save as" operation.

       @param dir the directory the file was saved in
    */
    public static void setLastSaveAsDir(File dir){
	lastSaveAsDir = dir;
    }


    /**
       Set the last directory used for an "open" operation.

       @param dir the directory the file was opened from
    */
    public static void setLastOpenDir(File dir){
	lastOpenDir = dir;
    }

    /**
       Retrieve the last directory used for a "save as" operation.

       @return the directory the file was saved in
    */
    public static File getLastSaveAsDir(){
	// default to last open dir if not set
	if ( lastSaveAsDir == null ){
	    lastSaveAsDir = lastOpenDir;
	}
	return lastSaveAsDir;
    }

     /**
       Retrieve the last directory used for an "open" operation.

       @return the directory the file was opened from
    */
    public static File getLastOpenDir(){
	return lastOpenDir;
    }


}
