/*
    Copyright 2004 James Nash
                                                                                                
    This file is part of Ganesha.
                                                                                                
    Ganesha is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.
                                                                                                
    Ganesha is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU General Public License for more details.
                                                                                                
    You should have received a copy of the GNU General Public License
    along with Ganesha (see the LICENSE file); if not, write to the Free
    Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
    MA  02111-1307  USA
                                                                                                
*/
package com.twiddles.ganesha.functionality;

import com.hp.hpl.jena.rdf.model.*;
import com.hp.hpl.jena.vocabulary.*;
import java.util.*;
/**
   Implementation of {@link RDFSeq} using Jena.
   <p>
   This requires the <a href="http://jena.sourceforge.net/">Jena API</a>
   to be installed on your system and listed in java's CLASSPATH.

   @see JenaBag
   @see JenaAlt
   @author James Nash
*/
public class JenaSeq extends JenaContainerAdaptor implements RDFSeq{

    /**
       Constructs a new JenaSeq.

       @param seq the Jena API Seq object to use
    */
    public JenaSeq(Seq seq){
	super(seq);
    }


    /**
       Removes the object at the specified position from this bag.

       @param index the index of the element to be deleted.
    */
    public void removeObject(int index){

	// convert container to Jena Seq
	Seq seq = (Seq) con;

	seq.remove(index);

    }

    /**
       Moves an object to a different position in the sequence.
       The indices of the other objects in the sequence are
       adjusted accordingly.

       @param from the index of the object to be moved
       @param to the position it should be moved to
    */
    public void move(int from, int to){

	// convert container to Jena Seq
	Seq seq = (Seq) con;

	RDFNode tmp = seq.getObject(from);
	
	if ( from < to ){
	    // moving further back in the sequence
	    
	    // shift down following elements
	    for (int i=from; i<to; i++){
		
		seq.set( i, seq.getObject(i+1) );

	    }
	    // put element we are moving to its destination
	    seq.set( to, tmp);

	}
	else if( from > to){
	    // moving forward in the sequence
	    
	    // shift up following elements
	    for (int i=from; i>to; i--){
		
		//System.out.println("doing something!");
		seq.set( i, seq.getObject(i-1) );

	    }
	    // put element we are moving to its destination
	    seq.set( to, tmp);

	}
	// if from == to do nothing!

    }

}
