/*
    Copyright 2004 James Nash
                                                                                                
    This file is part of Ganesha.
                                                                                                
    Ganesha is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.
                                                                                                
    Ganesha is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU General Public License for more details.
                                                                                                
    You should have received a copy of the GNU General Public License
    along with Ganesha (see the LICENSE file); if not, write to the Free
    Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
    MA  02111-1307  USA
                                                                                                
*/
package com.twiddles.ganesha.functionality;

/**
   Interface for querying the predicate of an RDF resource's property.
   A property has a type which is normally a URI to uniquely identify
   that property type.
   <p>
   Ganesha adds a description field to properties. This is intended to
   be a short, descriptive name for the property type and is
   displayed to the user in the GUI rather than the full URI.

   @author James Nash
*/
public interface RDFPredicate{

    /**
       Gets the type of this property.
       Usually a URI of some kind.

       @return type of property
    */
    String getType();

    /**
       Gets brief descriptive name for this property.

       @return short description
    */
    String getDescr();

}
