/*
    Copyright 2004 James Nash
                                                                                                
    This file is part of Ganesha.
                                                                                                
    Ganesha is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.
                                                                                                
    Ganesha is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU General Public License for more details.
                                                                                                
    You should have received a copy of the GNU General Public License
    along with Ganesha (see the LICENSE file); if not, write to the Free
    Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
    MA  02111-1307  USA
                                                                                                
*/
package com.twiddles.ganesha.functionality;

/**
   Interface for querying and modifying properties of an RDF resource.
   A property consists of a property type and a corresponding value.
   Since this property is describing a resource its type is the <em>predicate</em> and
   its value is the <em>object</em> of a property statement where the resource is the
   <em>subject</em>.

   @see RDFPredicate
   @see RDFObject
   @author James Nash
*/
public interface RDFProperty{


    /**
       Sets the object of this property.

       @param obj The object (aka value) to use
    */
    void setObject( RDFObject obj );

    /**
       Sets the object of this property to a literal value.
       Shorthand method to save making a literal <code>RDFObject</code> first.

       @param obj the literal value of the object of this property
    */
    void setObject( String obj );


    /**
       Query this property's predicate.
       
       @return the predicate
    */
    RDFPredicate getPredicate();

    /**
       Query this property's object.

       @return the object
    */
    RDFObject getObject();


    /**
       Remove's this property.
    */
    void delete();


}
