/*
    Copyright 2004 James Nash
                                                                                                
    This file is part of Ganesha.
                                                                                                
    Ganesha is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.
                                                                                                
    Ganesha is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU General Public License for more details.
                                                                                                
    You should have received a copy of the GNU General Public License
    along with Ganesha (see the LICENSE file); if not, write to the Free
    Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
    MA  02111-1307  USA
                                                                                                
*/
package com.twiddles.ganesha.gui;

import javax.swing.*;
import com.twiddles.ganesha.gui.gfx.*;
import java.awt.*;
/**
   The internal desktop area of the main Ganesha window.
   This is the main work surface in the GUI where internal windows
   such as resource editing windows appear.

   @author James Nash
*/
class GDesktop extends JDesktopPane{

    /**
       Reference to the main app window.
    */
    private final GUI window;

    /**
       Keep track of where the last window appeared
    */
    private Point lastWindowLocation;




    /**
       Creates a fully functioning internal
       desktop for the Ganesha app.

       @param window reference to main app window that contains this desktop
    */
    public GDesktop( GUI window ){
	super();

	this.window = window;
	this.lastWindowLocation = new Point(0,0);
	
	// ???
	this.setOpaque(false);

    }
    
    /**
       Reset the start location of windows.
    */
    public void resetLocation(){

	lastWindowLocation = new Point(0,0);

    }


    /**
       Get the next location at which to place a new window.
    */
    public Point getNextLocation(){

	// keep the current location to return...
	Point old = lastWindowLocation;

	// and increment our record for next time...
	int newX = (int) lastWindowLocation.getX();
	int newY = (int) lastWindowLocation.getY();
	    
	newX += 10;
	newY += 10;

	// if the new position would place the window (partly) outside the visible
	// desktop reset the coordinates...
	if ( newX >= ( getWidth() - ResourceWindow.DEFAULT_WIDTH ) ){
	    newX = 0;
	}

	if ( newY >= ( getHeight() - ResourceWindow.DEFAULT_HEIGHT ) ){
	    newY = 0;
	}

	lastWindowLocation = new Point(newX,newY);

	return old;
    }       



}
