/*
    Copyright 2004 James Nash
                                                                                                
    This file is part of Ganesha.
                                                                                                
    Ganesha is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.
                                                                                                
    Ganesha is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU General Public License for more details.
                                                                                                
    You should have received a copy of the GNU General Public License
    along with Ganesha (see the LICENSE file); if not, write to the Free
    Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
    MA  02111-1307  USA
                                                                                                
*/
package com.twiddles.ganesha.gui;

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;

/**
  ActionListener to control the exit behaviour of Ganesha's main window.  
  The {@link GUI} class uses this class as an action listener for window
  events.

  @author James Nash
 */
class GUIWindowListener extends WindowAdapter{

    /**
       reference to the GUI object that instanciates this class
    */
    private GUI window;

    /**
       Constructs a new <code>GUIWindowListener</code>.

       @param window the <code>GUI</code> object will be listened to
    */
    public GUIWindowListener(GUI window){
	this.window = window;
    }

    /**
       Method that controls what happens as Ganesha closes down.
       Rather than just closing the window and abruptly killing the
       whole app the {@link GUI} classes <code>shutdown()</code> method
       will be called when the user attempts to close the application
       window.

       @param w ignored
       @see GUI#shutdown()
    */
    public void windowClosing(WindowEvent w){

	// tell Ganesha to shutdown
	window.shutdown();

    }

}
