/*
    Copyright 2004 James Nash
                                                                                                
    This file is part of Ganesha.
                                                                                                
    Ganesha is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.
                                                                                                
    Ganesha is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU General Public License for more details.
                                                                                                
    You should have received a copy of the GNU General Public License
    along with Ganesha (see the LICENSE file); if not, write to the Free
    Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
    MA  02111-1307  USA
                                                                                                
*/
package com.twiddles.ganesha.gui;
import javax.swing.event.*;
import com.twiddles.ganesha.gui.gfx.*;

/**

   ActionListener to control the exit behaviour of a Resource window.
   
   @author James Nash
*/
class ResourceWindowListener extends InternalFrameAdapter{

    /**
       Reference to the resource list entry whose window is being listened to.
    */
    private ResourceListEntry resEnt;

    /**
       Reference to the resource list that contains the entry
    */
    private ResourceList resList;


    /**
       Constructs a Listener that is linked to a given Resource list entry.

       @param resEnt the resource list entry whose window is being listened to
    */
    public ResourceWindowListener (ResourceListEntry resEnt, ResourceList resList ){
	
	this.resEnt = resEnt;
	this.resList = resList;

    }

    /**
        Invoked when an internal frame has been opened.

	@param e ignored
    */
    public void internalFrameOpened( InternalFrameEvent e ){

	resEnt.setStatIcon( GUIIcons.getIcon( GUIIcons.WINDOW_OPEN_ICON ) );
	resList.refresh();
	
    }

    /**
        Invoked when an internal frame has been de-iconified.

	@param e ignored
    */
    public void internalFrameDeiconified( InternalFrameEvent e ){

	resEnt.setStatIcon( GUIIcons.getIcon( GUIIcons.WINDOW_OPEN_ICON ) );
	resList.refresh();
	
    }

    /**
        Invoked when an internal frame has been iconified.

	@param e ignored
    */
    public void internalFrameIconified( InternalFrameEvent e ){

	resEnt.setStatIcon( GUIIcons.getIcon( GUIIcons.WINDOW_ICONIFIED_ICON ) );
	resList.refresh();
	
    }


    /**
        Invoked when an internal frame has been closed.

	@param e ignored
    */
    public void internalFrameClosed( InternalFrameEvent e ){

	resEnt.setStatIcon( GUIIcons.getIcon( GUIIcons.WINDOW_CLOSED_ICON ) );
	resEnt.closeWindow();
	resList.refresh();

	
    }



}
