/*
    Copyright 2004 James Nash
                                                                                                
    This file is part of Ganesha.
                                                                                                
    Ganesha is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.
                                                                                                
    Ganesha is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU General Public License for more details.
                                                                                                
    You should have received a copy of the GNU General Public License
    along with Ganesha (see the LICENSE file); if not, write to the Free
    Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
    MA  02111-1307  USA
                                                                                                
*/
package com.twiddles.ganesha.gui;

import java.awt.*;
import javax.swing.*;
import java.awt.event.*;

/**
   ActionListener to switch the GUI's look and feel.

   @author James Nash
*/
class SkinEvent implements ActionListener{

    /**
       Reference to the main app window
    */
    private GUI window;

    /**
       The classname of the Java Swing look and feel that should
       be used
    */
    private String skin;

    /**
       Constructs a new SkinEvent that can change
       the given window's skin.

       @param window the window whose LnF should be altered
       @param skin the classname of the Java Swing LnF to use
    */
    public SkinEvent( GUI window, String skin){
	this.window = window;
	this.skin = skin;
    }

    /**
       Switches the Look and Feel to that specified to the constructor.

       @param e ignored
       @see #SkinEvent(GUI, String)
    */
    public void actionPerformed(ActionEvent e){
	window.switchLNF(skin);
    }

}
